#[non_exhaustive]pub enum LdkClientInitError {
MissingEsploraHost,
InvalidDataDir,
Build(BuildError),
Start(NodeError),
}Expand description
A failure to create the LDK Lightning node behind a GatewayLdkClient.
Creating the client configures an LDK node from the gateway’s settings, builds it on top of the data directory and starts it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MissingEsploraHost
The Esplora chain source’s URL names no host to connect to.
InvalidDataDir
The data directory’s path is not valid UTF-8, which LDK needs for its storage path.
Build(BuildError)
LDK could not build the node, for example because its storage could not be read or was created for another network.
Start(NodeError)
LDK built the node but could not start it.